==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ToolCommandEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var ToolCommandEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ToolCommandEventArgsDescription, _super);
    function ToolCommandEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        return _this;
    }
    ToolCommandEventArgsDescription.prototype.get_type = function () {
        return "ToolCommandEventArgs";
    };
    Object.defineProperty(ToolCommandEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ToolCommandEventArgsDescription.prototype, "command", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Command");
        },
        enumerable: true,
        configurable: true
    });
    ToolCommandEventArgsDescription.$t = markType(ToolCommandEventArgsDescription, 'ToolCommandEventArgsDescription', Description.$);
    return ToolCommandEventArgsDescription;
}(Description));
export { ToolCommandEventArgsDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/ToolCommandEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var ToolCommandEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolCommandEventArgsDescription, _super);
    function ToolCommandEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        _this.j = false;
        return _this;
    }
    ToolCommandEventArgsDescription.prototype.get_type = function () {
        return "ToolCommandEventArgs";
    };
    Object.defineProperty(ToolCommandEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ToolCommandEventArgsDescription.prototype, "command", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Command");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ToolCommandEventArgsDescription.prototype, "closeOnExecute", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("CloseOnExecute");
        },
        enumerable: false,
        configurable: true
    });
    ToolCommandEventArgsDescription.$t = markType(ToolCommandEventArgsDescription, 'ToolCommandEventArgsDescription', Description.$);
    return ToolCommandEventArgsDescription;
}(Description));
export { ToolCommandEventArgsDescription };
